// @generated
// This file is @generated by prost-build.
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateChannelSchemaRequest {
    #[prost(string, tag="1")]
    pub component: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub channel: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub unit: ::prost::alloc::string::String,
    #[prost(enumeration="super::super::common::r#type::v1::ChannelDataType", tag="4")]
    pub data_type: i32,
    #[prost(message, repeated, tag="5")]
    pub enum_types: ::prost::alloc::vec::Vec<super::super::common::r#type::v1::ChannelEnumType>,
    #[prost(message, repeated, tag="6")]
    pub bit_field_elements: ::prost::alloc::vec::Vec<super::super::common::r#type::v1::ChannelBitFieldElement>,
    #[prost(string, tag="7")]
    pub asset_name: ::prost::alloc::string::String,
    #[prost(string, tag="8")]
    pub organization_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct CreateChannelSchemaResponse {
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct BatchCreateChannelSchemasRequest {
    #[prost(message, repeated, tag="1")]
    pub requests: ::prost::alloc::vec::Vec<CreateChannelSchemaRequest>,
    #[prost(string, tag="2")]
    pub asset_name: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub organization_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct BatchCreateChannelSchemasResponse {
}
include!("sift.channel_schemas.v1.tonic.rs");
include!("sift.channel_schemas.v1.serde.rs");
// @@protoc_insertion_point(module)