// @generated
// This file is @generated by prost-build.
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct IngestWithConfigDataStreamRequest {
    #[prost(string, tag="1")]
    pub ingestion_config_id: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub flow: ::prost::alloc::string::String,
    #[prost(message, optional, tag="3")]
    pub timestamp: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(message, repeated, tag="4")]
    pub channel_values: ::prost::alloc::vec::Vec<IngestWithConfigDataChannelValue>,
    #[prost(string, tag="5")]
    pub run_id: ::prost::alloc::string::String,
    #[prost(bool, tag="6")]
    pub end_stream_on_validation_error: bool,
    #[prost(string, tag="7")]
    pub organization_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct IngestWithConfigDataStreamResponse {
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct IngestWithConfigDataChannelValue {
    #[prost(oneof="ingest_with_config_data_channel_value::Type", tags="1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12")]
    pub r#type: ::core::option::Option<ingest_with_config_data_channel_value::Type>,
}
/// Nested message and enum types in `IngestWithConfigDataChannelValue`.
pub mod ingest_with_config_data_channel_value {
    #[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Oneof)]
    pub enum Type {
        #[prost(string, tag="1")]
        String(::prost::alloc::string::String),
        #[prost(double, tag="2")]
        Double(f64),
        #[prost(float, tag="3")]
        Float(f32),
        #[prost(bool, tag="4")]
        Bool(bool),
        #[prost(int32, tag="5")]
        Int32(i32),
        #[prost(uint32, tag="6")]
        Uint32(u32),
        #[prost(int64, tag="7")]
        Int64(i64),
        #[prost(uint64, tag="8")]
        Uint64(u64),
        #[prost(bytes, tag="9")]
        BitField(::prost::alloc::vec::Vec<u8>),
        #[prost(uint32, tag="10")]
        Enum(u32),
        #[prost(message, tag="11")]
        Empty(::pbjson_types::Empty),
        #[prost(bytes, tag="12")]
        Bytes(::prost::alloc::vec::Vec<u8>),
    }
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct IngestArbitraryProtobufDataStreamRequest {
    #[prost(string, tag="1")]
    pub message_type_identifier: ::prost::alloc::string::String,
    #[prost(string, optional, tag="2")]
    pub message_type_display_name: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, tag="3")]
    pub asset_name: ::prost::alloc::string::String,
    #[prost(message, optional, tag="4")]
    pub timestamp: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(bytes="vec", tag="5")]
    pub value: ::prost::alloc::vec::Vec<u8>,
    #[prost(string, tag="6")]
    pub run_id: ::prost::alloc::string::String,
    #[prost(string, tag="7")]
    pub namespace: ::prost::alloc::string::String,
    #[prost(string, tag="8")]
    pub organization_id: ::prost::alloc::string::String,
    #[prost(bool, tag="9")]
    pub end_stream_on_validation_error: bool,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct IngestArbitraryProtobufDataStreamResponse {
}
include!("sift.ingest.v1.tonic.rs");
include!("sift.ingest.v1.serde.rs");
// @@protoc_insertion_point(module)