// @generated
// This file is @generated by prost-build.
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct RemoteFile {
    #[prost(string, tag="1")]
    pub remote_file_id: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub organization_id: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub entity_id: ::prost::alloc::string::String,
    #[prost(enumeration="EntityType", tag="4")]
    pub entity_type: i32,
    #[prost(string, tag="5")]
    pub file_name: ::prost::alloc::string::String,
    #[prost(string, tag="6")]
    pub file_mime_type: ::prost::alloc::string::String,
    #[prost(string, tag="7")]
    pub file_content_encoding: ::prost::alloc::string::String,
    #[prost(string, tag="8")]
    pub storage_key: ::prost::alloc::string::String,
    #[prost(uint64, tag="9")]
    pub file_size: u64,
    #[prost(string, optional, tag="10")]
    pub description: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, tag="13")]
    pub created_by_user_id: ::prost::alloc::string::String,
    #[prost(string, tag="14")]
    pub modified_by_user_id: ::prost::alloc::string::String,
    #[prost(message, optional, tag="15")]
    pub created_date: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(message, optional, tag="16")]
    pub modified_date: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(message, repeated, tag="18")]
    pub metadata_values: ::prost::alloc::vec::Vec<super::super::metadata::v1::MetadataValue>,
    #[prost(oneof="remote_file::Metadata", tags="11, 12, 17")]
    pub metadata: ::core::option::Option<remote_file::Metadata>,
}
/// Nested message and enum types in `RemoteFile`.
pub mod remote_file {
    #[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Oneof)]
    pub enum Metadata {
        #[prost(message, tag="11")]
        VideoMetadata(super::VideoMetadata),
        #[prost(message, tag="12")]
        ImageMetadata(super::ImageMetadata),
        #[prost(message, tag="17")]
        AudioMetadata(super::AudioMetadata),
    }
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct VideoMetadata {
    #[prost(uint32, tag="1")]
    pub height: u32,
    #[prost(uint32, tag="2")]
    pub width: u32,
    #[prost(float, tag="3")]
    pub duration_seconds: f32,
    #[prost(message, optional, tag="4")]
    pub timestamp: ::core::option::Option<::pbjson_types::Timestamp>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct ImageMetadata {
    #[prost(uint32, tag="1")]
    pub height: u32,
    #[prost(uint32, tag="2")]
    pub width: u32,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct AudioMetadata {
    #[prost(float, tag="1")]
    pub duration_seconds: f32,
    #[prost(message, optional, tag="2")]
    pub timestamp: ::core::option::Option<::pbjson_types::Timestamp>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetRemoteFileRequest {
    #[prost(string, tag="1")]
    pub remote_file_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetRemoteFileResponse {
    #[prost(message, optional, tag="1")]
    pub remote_file: ::core::option::Option<RemoteFile>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListRemoteFilesRequest {
    #[prost(uint32, tag="1")]
    pub page_size: u32,
    #[prost(string, tag="2")]
    pub page_token: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub filter: ::prost::alloc::string::String,
    #[prost(string, tag="4")]
    pub organization_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListRemoteFilesResponse {
    #[prost(message, repeated, tag="1")]
    pub remote_files: ::prost::alloc::vec::Vec<RemoteFile>,
    #[prost(string, tag="2")]
    pub next_page_token: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateRemoteFileRequest {
    #[prost(string, tag="1")]
    pub file_name: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub entity_id: ::prost::alloc::string::String,
    #[prost(enumeration="EntityType", tag="3")]
    pub entity_type: i32,
    #[prost(string, tag="4")]
    pub file_mime_type: ::prost::alloc::string::String,
    #[prost(string, tag="5")]
    pub file_content_encoding: ::prost::alloc::string::String,
    #[prost(uint64, tag="6")]
    pub file_size: u64,
    #[prost(string, optional, tag="7")]
    pub description: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, tag="8")]
    pub organization_id: ::prost::alloc::string::String,
    #[prost(string, optional, tag="11")]
    pub custom_uuid: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(message, repeated, tag="13")]
    pub metadata_values: ::prost::alloc::vec::Vec<super::super::metadata::v1::MetadataValue>,
    #[prost(oneof="create_remote_file_request::Metadata", tags="9, 10, 12")]
    pub metadata: ::core::option::Option<create_remote_file_request::Metadata>,
}
/// Nested message and enum types in `CreateRemoteFileRequest`.
pub mod create_remote_file_request {
    #[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Oneof)]
    pub enum Metadata {
        #[prost(message, tag="9")]
        VideoMetadata(super::VideoMetadata),
        #[prost(message, tag="10")]
        ImageMetadata(super::ImageMetadata),
        #[prost(message, tag="12")]
        AudioMetadata(super::AudioMetadata),
    }
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateRemoteFileResponse {
    #[prost(message, optional, tag="1")]
    pub remote_file: ::core::option::Option<RemoteFile>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteRemoteFileRequest {
    #[prost(string, tag="1")]
    pub remote_file_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct DeleteRemoteFileResponse {
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct BatchDeleteRemoteFilesRequest {
    #[prost(string, repeated, tag="1")]
    pub remote_file_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct BatchDeleteRemoteFilesResponse {
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateRemoteFileRequest {
    #[prost(message, optional, tag="1")]
    pub remote_file: ::core::option::Option<RemoteFile>,
    #[prost(message, optional, tag="2")]
    pub update_mask: ::core::option::Option<::pbjson_types::FieldMask>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateRemoteFileResponse {
    #[prost(message, optional, tag="1")]
    pub remote_file: ::core::option::Option<RemoteFile>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetRemoteFileDownloadUrlRequest {
    #[prost(string, tag="1")]
    pub remote_file_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetRemoteFileDownloadUrlResponse {
    #[prost(string, tag="1")]
    pub download_url: ::prost::alloc::string::String,
}
#[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
#[repr(i32)]
pub enum EntityType {
    Unspecified = 0,
    Run = 1,
    Annotation = 2,
    Asset = 3,
    AnnotationLog = 4,
    TestReport = 5,
}
impl EntityType {
    /// String value of the enum field names used in the ProtoBuf definition.
    ///
    /// The values are not transformed in any way and thus are considered stable
    /// (if the ProtoBuf definition does not change) and safe for programmatic use.
    pub fn as_str_name(&self) -> &'static str {
        match self {
            EntityType::Unspecified => "ENTITY_TYPE_UNSPECIFIED",
            EntityType::Run => "ENTITY_TYPE_RUN",
            EntityType::Annotation => "ENTITY_TYPE_ANNOTATION",
            EntityType::Asset => "ENTITY_TYPE_ASSET",
            EntityType::AnnotationLog => "ENTITY_TYPE_ANNOTATION_LOG",
            EntityType::TestReport => "ENTITY_TYPE_TEST_REPORT",
        }
    }
    /// Creates an enum from field names used in the ProtoBuf definition.
    pub fn from_str_name(value: &str) -> ::core::option::Option<Self> {
        match value {
            "ENTITY_TYPE_UNSPECIFIED" => Some(Self::Unspecified),
            "ENTITY_TYPE_RUN" => Some(Self::Run),
            "ENTITY_TYPE_ANNOTATION" => Some(Self::Annotation),
            "ENTITY_TYPE_ASSET" => Some(Self::Asset),
            "ENTITY_TYPE_ANNOTATION_LOG" => Some(Self::AnnotationLog),
            "ENTITY_TYPE_TEST_REPORT" => Some(Self::TestReport),
            _ => None,
        }
    }
}
include!("sift.remote_files.v1.tonic.rs");
include!("sift.remote_files.v1.serde.rs");
// @@protoc_insertion_point(module)