// @generated
// This file is @generated by prost-build.
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UserAttributeKey {
    #[prost(string, tag="1")]
    pub user_attribute_key_id: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub organization_id: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub name: ::prost::alloc::string::String,
    #[prost(string, tag="4")]
    pub description: ::prost::alloc::string::String,
    #[prost(enumeration="UserAttributeValueType", tag="5")]
    pub r#type: i32,
    #[prost(message, optional, tag="6")]
    pub created_date: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(string, tag="7")]
    pub created_by_user_id: ::prost::alloc::string::String,
    #[prost(message, optional, tag="8")]
    pub modified_date: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(string, tag="9")]
    pub modified_by_user_id: ::prost::alloc::string::String,
    #[prost(message, optional, tag="10")]
    pub archived_date: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(bool, tag="11")]
    pub is_archived: bool,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateUserAttributeKeyRequest {
    #[prost(string, tag="1")]
    pub name: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub description: ::prost::alloc::string::String,
    #[prost(enumeration="UserAttributeValueType", tag="3")]
    pub r#type: i32,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateUserAttributeKeyResponse {
    #[prost(message, optional, tag="1")]
    pub user_attribute_key: ::core::option::Option<UserAttributeKey>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateUserAttributeKeyRequest {
    #[prost(string, tag="1")]
    pub user_attribute_key_id: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub name: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub description: ::prost::alloc::string::String,
    #[prost(message, optional, tag="4")]
    pub update_mask: ::core::option::Option<::pbjson_types::FieldMask>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateUserAttributeKeyResponse {
    #[prost(message, optional, tag="1")]
    pub user_attribute_key: ::core::option::Option<UserAttributeKey>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetUserAttributeKeyRequest {
    #[prost(string, tag="1")]
    pub user_attribute_key_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetUserAttributeKeyResponse {
    #[prost(message, optional, tag="1")]
    pub user_attribute_key: ::core::option::Option<UserAttributeKey>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListUserAttributeKeysRequest {
    #[prost(uint32, tag="1")]
    pub page_size: u32,
    #[prost(string, tag="2")]
    pub page_token: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub filter: ::prost::alloc::string::String,
    #[prost(string, tag="4")]
    pub order_by: ::prost::alloc::string::String,
    #[prost(string, tag="5")]
    pub organization_id: ::prost::alloc::string::String,
    #[prost(bool, tag="6")]
    pub include_archived: bool,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListUserAttributeKeysResponse {
    #[prost(message, repeated, tag="1")]
    pub user_attribute_keys: ::prost::alloc::vec::Vec<UserAttributeKey>,
    #[prost(string, tag="2")]
    pub next_page_token: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ArchiveUserAttributeKeysRequest {
    #[prost(string, repeated, tag="1")]
    pub user_attribute_key_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct ArchiveUserAttributeKeysResponse {
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UnarchiveUserAttributeKeysRequest {
    #[prost(string, repeated, tag="1")]
    pub user_attribute_key_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct UnarchiveUserAttributeKeysResponse {
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UserAttributeValue {
    #[prost(string, tag="1")]
    pub user_attribute_value_id: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub user_attribute_key_id: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub user_id: ::prost::alloc::string::String,
    #[prost(string, tag="4")]
    pub organization_id: ::prost::alloc::string::String,
    #[prost(string, tag="8")]
    pub created_by_user_id: ::prost::alloc::string::String,
    #[prost(message, optional, tag="9")]
    pub created_date: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(message, optional, tag="10")]
    pub archived_date: ::core::option::Option<::pbjson_types::Timestamp>,
    #[prost(bool, tag="11")]
    pub is_archived: bool,
    #[prost(message, optional, tag="12")]
    pub key: ::core::option::Option<UserAttributeKey>,
    #[prost(oneof="user_attribute_value::Value", tags="5, 6, 7")]
    pub value: ::core::option::Option<user_attribute_value::Value>,
}
/// Nested message and enum types in `UserAttributeValue`.
pub mod user_attribute_value {
    #[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Oneof)]
    pub enum Value {
        #[prost(string, tag="5")]
        StringValue(::prost::alloc::string::String),
        #[prost(double, tag="6")]
        NumberValue(f64),
        #[prost(bool, tag="7")]
        BooleanValue(bool),
    }
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateUserAttributeValueRequest {
    #[prost(string, tag="1")]
    pub user_attribute_key_id: ::prost::alloc::string::String,
    #[prost(string, tag="2")]
    pub user_id: ::prost::alloc::string::String,
    #[prost(oneof="create_user_attribute_value_request::Value", tags="4, 5, 6")]
    pub value: ::core::option::Option<create_user_attribute_value_request::Value>,
}
/// Nested message and enum types in `CreateUserAttributeValueRequest`.
pub mod create_user_attribute_value_request {
    #[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Oneof)]
    pub enum Value {
        #[prost(string, tag="4")]
        StringValue(::prost::alloc::string::String),
        #[prost(double, tag="5")]
        NumberValue(f64),
        #[prost(bool, tag="6")]
        BooleanValue(bool),
    }
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateUserAttributeValueResponse {
    #[prost(message, optional, tag="1")]
    pub user_attribute_value: ::core::option::Option<UserAttributeValue>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct BatchCreateUserAttributeValueRequest {
    #[prost(string, tag="1")]
    pub user_attribute_key_id: ::prost::alloc::string::String,
    #[prost(string, repeated, tag="2")]
    pub user_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
    #[prost(oneof="batch_create_user_attribute_value_request::Value", tags="3, 4, 5")]
    pub value: ::core::option::Option<batch_create_user_attribute_value_request::Value>,
}
/// Nested message and enum types in `BatchCreateUserAttributeValueRequest`.
pub mod batch_create_user_attribute_value_request {
    #[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Oneof)]
    pub enum Value {
        #[prost(string, tag="3")]
        StringValue(::prost::alloc::string::String),
        #[prost(double, tag="4")]
        NumberValue(f64),
        #[prost(bool, tag="5")]
        BooleanValue(bool),
    }
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct BatchCreateUserAttributeValueResponse {
    #[prost(message, repeated, tag="1")]
    pub user_attribute_values: ::prost::alloc::vec::Vec<UserAttributeValue>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListUserAttributeKeyValuesRequest {
    #[prost(string, tag="1")]
    pub user_attribute_key_id: ::prost::alloc::string::String,
    #[prost(uint32, tag="2")]
    pub page_size: u32,
    #[prost(string, tag="3")]
    pub page_token: ::prost::alloc::string::String,
    #[prost(string, tag="4")]
    pub filter: ::prost::alloc::string::String,
    #[prost(string, tag="5")]
    pub order_by: ::prost::alloc::string::String,
    #[prost(bool, tag="6")]
    pub include_archived: bool,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListUserAttributeKeyValuesResponse {
    #[prost(message, repeated, tag="1")]
    pub user_attribute_values: ::prost::alloc::vec::Vec<UserAttributeValue>,
    #[prost(string, tag="2")]
    pub next_page_token: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListUserAttributeValuesRequest {
    #[prost(uint32, tag="1")]
    pub page_size: u32,
    #[prost(string, tag="2")]
    pub page_token: ::prost::alloc::string::String,
    #[prost(string, tag="3")]
    pub filter: ::prost::alloc::string::String,
    #[prost(string, tag="4")]
    pub order_by: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListUserAttributeValuesResponse {
    #[prost(message, repeated, tag="1")]
    pub user_attribute_values: ::prost::alloc::vec::Vec<UserAttributeValue>,
    #[prost(string, tag="2")]
    pub next_page_token: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetUserAttributeValueRequest {
    #[prost(string, tag="1")]
    pub user_attribute_value_id: ::prost::alloc::string::String,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetUserAttributeValueResponse {
    #[prost(message, optional, tag="1")]
    pub user_attribute_value: ::core::option::Option<UserAttributeValue>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ArchiveUserAttributeValuesRequest {
    #[prost(string, repeated, tag="1")]
    pub user_attribute_value_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct ArchiveUserAttributeValuesResponse {
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UnarchiveUserAttributeValuesRequest {
    #[prost(string, repeated, tag="1")]
    pub user_attribute_value_ids: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
}
#[allow(clippy::derive_partial_eq_without_eq)]
#[derive(Clone, Copy, PartialEq, ::prost::Message)]
pub struct UnarchiveUserAttributeValuesResponse {
}
#[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
#[repr(i32)]
pub enum UserAttributeValueType {
    Unspecified = 0,
    String = 1,
    Boolean = 2,
    Number = 3,
    SetOfString = 4,
}
impl UserAttributeValueType {
    /// String value of the enum field names used in the ProtoBuf definition.
    ///
    /// The values are not transformed in any way and thus are considered stable
    /// (if the ProtoBuf definition does not change) and safe for programmatic use.
    pub fn as_str_name(&self) -> &'static str {
        match self {
            UserAttributeValueType::Unspecified => "USER_ATTRIBUTE_VALUE_TYPE_UNSPECIFIED",
            UserAttributeValueType::String => "USER_ATTRIBUTE_VALUE_TYPE_STRING",
            UserAttributeValueType::Boolean => "USER_ATTRIBUTE_VALUE_TYPE_BOOLEAN",
            UserAttributeValueType::Number => "USER_ATTRIBUTE_VALUE_TYPE_NUMBER",
            UserAttributeValueType::SetOfString => "USER_ATTRIBUTE_VALUE_TYPE_SET_OF_STRING",
        }
    }
    /// Creates an enum from field names used in the ProtoBuf definition.
    pub fn from_str_name(value: &str) -> ::core::option::Option<Self> {
        match value {
            "USER_ATTRIBUTE_VALUE_TYPE_UNSPECIFIED" => Some(Self::Unspecified),
            "USER_ATTRIBUTE_VALUE_TYPE_STRING" => Some(Self::String),
            "USER_ATTRIBUTE_VALUE_TYPE_BOOLEAN" => Some(Self::Boolean),
            "USER_ATTRIBUTE_VALUE_TYPE_NUMBER" => Some(Self::Number),
            "USER_ATTRIBUTE_VALUE_TYPE_SET_OF_STRING" => Some(Self::SetOfString),
            _ => None,
        }
    }
}
include!("sift.user_attributes.v1.tonic.rs");
include!("sift.user_attributes.v1.serde.rs");
// @@protoc_insertion_point(module)