// @generated
pub mod buf {
    // @@protoc_insertion_point(attribute:buf.validate)
    pub mod validate {
        include!("buf.validate.rs");
        // @@protoc_insertion_point(buf.validate)
    }
}
pub mod google {
    // @@protoc_insertion_point(attribute:google.api)
    pub mod api {
        include!("google.api.rs");
        // @@protoc_insertion_point(google.api)
    }
}
pub mod grpc {
    pub mod gateway {
        pub mod protoc_gen_openapiv2 {
            // @@protoc_insertion_point(attribute:grpc.gateway.protoc_gen_openapiv2.options)
            pub mod options {
                include!("grpc.gateway.protoc_gen_openapiv2.options.rs");
                // @@protoc_insertion_point(grpc.gateway.protoc_gen_openapiv2.options)
            }
        }
    }
}
pub mod sift {
    pub mod annotation_logs {
        // @@protoc_insertion_point(attribute:sift.annotation_logs.v1)
        pub mod v1 {
            include!("sift.annotation_logs.v1.rs");
            // @@protoc_insertion_point(sift.annotation_logs.v1)
        }
    }
    pub mod annotations {
        // @@protoc_insertion_point(attribute:sift.annotations.v1)
        pub mod v1 {
            include!("sift.annotations.v1.rs");
            // @@protoc_insertion_point(sift.annotations.v1)
        }
    }
    pub mod api_keys {
        // @@protoc_insertion_point(attribute:sift.api_keys.v2)
        pub mod v2 {
            include!("sift.api_keys.v2.rs");
            // @@protoc_insertion_point(sift.api_keys.v2)
        }
    }
    pub mod assets {
        // @@protoc_insertion_point(attribute:sift.assets.v1)
        pub mod v1 {
            include!("sift.assets.v1.rs");
            // @@protoc_insertion_point(sift.assets.v1)
        }
    }
    pub mod calculated_channels {
        // @@protoc_insertion_point(attribute:sift.calculated_channels.v1)
        pub mod v1 {
            include!("sift.calculated_channels.v1.rs");
            // @@protoc_insertion_point(sift.calculated_channels.v1)
        }
        // @@protoc_insertion_point(attribute:sift.calculated_channels.v2)
        pub mod v2 {
            include!("sift.calculated_channels.v2.rs");
            // @@protoc_insertion_point(sift.calculated_channels.v2)
        }
    }
    pub mod campaigns {
        // @@protoc_insertion_point(attribute:sift.campaigns.v1)
        pub mod v1 {
            include!("sift.campaigns.v1.rs");
            // @@protoc_insertion_point(sift.campaigns.v1)
        }
    }
    pub mod channel_schemas {
        // @@protoc_insertion_point(attribute:sift.channel_schemas.v1)
        pub mod v1 {
            include!("sift.channel_schemas.v1.rs");
            // @@protoc_insertion_point(sift.channel_schemas.v1)
        }
        // @@protoc_insertion_point(attribute:sift.channel_schemas.v2)
        pub mod v2 {
            include!("sift.channel_schemas.v2.rs");
            // @@protoc_insertion_point(sift.channel_schemas.v2)
        }
    }
    pub mod channels {
        // @@protoc_insertion_point(attribute:sift.channels.v2)
        pub mod v2 {
            include!("sift.channels.v2.rs");
            // @@protoc_insertion_point(sift.channels.v2)
        }
        // @@protoc_insertion_point(attribute:sift.channels.v3)
        pub mod v3 {
            include!("sift.channels.v3.rs");
            // @@protoc_insertion_point(sift.channels.v3)
        }
    }
    pub mod common {
        pub mod r#type {
            // @@protoc_insertion_point(attribute:sift.common.type.v1)
            pub mod v1 {
                include!("sift.common.type.v1.rs");
                // @@protoc_insertion_point(sift.common.type.v1)
            }
        }
    }
    pub mod data {
        // @@protoc_insertion_point(attribute:sift.data.v1)
        pub mod v1 {
            include!("sift.data.v1.rs");
            // @@protoc_insertion_point(sift.data.v1)
        }
        // @@protoc_insertion_point(attribute:sift.data.v2)
        pub mod v2 {
            include!("sift.data.v2.rs");
            // @@protoc_insertion_point(sift.data.v2)
        }
    }
    pub mod data_imports {
        // @@protoc_insertion_point(attribute:sift.data_imports.v2)
        pub mod v2 {
            include!("sift.data_imports.v2.rs");
            // @@protoc_insertion_point(sift.data_imports.v2)
        }
    }
    pub mod dlq_errors {
        // @@protoc_insertion_point(attribute:sift.dlq_errors.v2)
        pub mod v2 {
            include!("sift.dlq_errors.v2.rs");
            // @@protoc_insertion_point(sift.dlq_errors.v2)
        }
    }
    pub mod exports {
        // @@protoc_insertion_point(attribute:sift.exports.v1)
        pub mod v1 {
            include!("sift.exports.v1.rs");
            // @@protoc_insertion_point(sift.exports.v1)
        }
    }
    pub mod external_sync {
        // @@protoc_insertion_point(attribute:sift.external_sync.v1)
        pub mod v1 {
            include!("sift.external_sync.v1.rs");
            // @@protoc_insertion_point(sift.external_sync.v1)
        }
    }
    pub mod ingest {
        // @@protoc_insertion_point(attribute:sift.ingest.v1)
        pub mod v1 {
            include!("sift.ingest.v1.rs");
            // @@protoc_insertion_point(sift.ingest.v1)
        }
    }
    pub mod ingestion_configs {
        // @@protoc_insertion_point(attribute:sift.ingestion_configs.v1)
        pub mod v1 {
            include!("sift.ingestion_configs.v1.rs");
            // @@protoc_insertion_point(sift.ingestion_configs.v1)
        }
        // @@protoc_insertion_point(attribute:sift.ingestion_configs.v2)
        pub mod v2 {
            include!("sift.ingestion_configs.v2.rs");
            // @@protoc_insertion_point(sift.ingestion_configs.v2)
        }
    }
    pub mod jobs {
        // @@protoc_insertion_point(attribute:sift.jobs.v1)
        pub mod v1 {
            include!("sift.jobs.v1.rs");
            // @@protoc_insertion_point(sift.jobs.v1)
        }
    }
    pub mod me {
        // @@protoc_insertion_point(attribute:sift.me.v2)
        pub mod v2 {
            include!("sift.me.v2.rs");
            // @@protoc_insertion_point(sift.me.v2)
        }
    }
    pub mod metadata {
        // @@protoc_insertion_point(attribute:sift.metadata.v1)
        pub mod v1 {
            include!("sift.metadata.v1.rs");
            // @@protoc_insertion_point(sift.metadata.v1)
        }
    }
    pub mod notifications {
        // @@protoc_insertion_point(attribute:sift.notifications.v1)
        pub mod v1 {
            include!("sift.notifications.v1.rs");
            // @@protoc_insertion_point(sift.notifications.v1)
        }
    }
    pub mod options {
        // @@protoc_insertion_point(attribute:sift.options.v1)
        pub mod v1 {
            include!("sift.options.v1.rs");
            // @@protoc_insertion_point(sift.options.v1)
        }
    }
    pub mod ping {
        // @@protoc_insertion_point(attribute:sift.ping.v1)
        pub mod v1 {
            include!("sift.ping.v1.rs");
            // @@protoc_insertion_point(sift.ping.v1)
        }
    }
    pub mod policies {
        // @@protoc_insertion_point(attribute:sift.policies.v1)
        pub mod v1 {
            include!("sift.policies.v1.rs");
            // @@protoc_insertion_point(sift.policies.v1)
        }
    }
    pub mod protobuf_descriptors {
        // @@protoc_insertion_point(attribute:sift.protobuf_descriptors.v2)
        pub mod v2 {
            include!("sift.protobuf_descriptors.v2.rs");
            // @@protoc_insertion_point(sift.protobuf_descriptors.v2)
        }
    }
    pub mod remote_files {
        // @@protoc_insertion_point(attribute:sift.remote_files.v1)
        pub mod v1 {
            include!("sift.remote_files.v1.rs");
            // @@protoc_insertion_point(sift.remote_files.v1)
        }
    }
    pub mod report_templates {
        // @@protoc_insertion_point(attribute:sift.report_templates.v1)
        pub mod v1 {
            include!("sift.report_templates.v1.rs");
            // @@protoc_insertion_point(sift.report_templates.v1)
        }
    }
    pub mod reports {
        // @@protoc_insertion_point(attribute:sift.reports.v1)
        pub mod v1 {
            include!("sift.reports.v1.rs");
            // @@protoc_insertion_point(sift.reports.v1)
        }
    }
    pub mod resource_attribute {
        // @@protoc_insertion_point(attribute:sift.resource_attribute.v1)
        pub mod v1 {
            include!("sift.resource_attribute.v1.rs");
            // @@protoc_insertion_point(sift.resource_attribute.v1)
        }
    }
    pub mod roles {
        // @@protoc_insertion_point(attribute:sift.roles.v2)
        pub mod v2 {
            include!("sift.roles.v2.rs");
            // @@protoc_insertion_point(sift.roles.v2)
        }
    }
    pub mod rule_evaluation {
        // @@protoc_insertion_point(attribute:sift.rule_evaluation.v1)
        pub mod v1 {
            include!("sift.rule_evaluation.v1.rs");
            // @@protoc_insertion_point(sift.rule_evaluation.v1)
        }
    }
    pub mod rules {
        // @@protoc_insertion_point(attribute:sift.rules.v1)
        pub mod v1 {
            include!("sift.rules.v1.rs");
            // @@protoc_insertion_point(sift.rules.v1)
        }
    }
    pub mod runs {
        // @@protoc_insertion_point(attribute:sift.runs.v2)
        pub mod v2 {
            include!("sift.runs.v2.rs");
            // @@protoc_insertion_point(sift.runs.v2)
        }
    }
    pub mod saved_searches {
        // @@protoc_insertion_point(attribute:sift.saved_searches.v1)
        pub mod v1 {
            include!("sift.saved_searches.v1.rs");
            // @@protoc_insertion_point(sift.saved_searches.v1)
        }
    }
    pub mod tags {
        // @@protoc_insertion_point(attribute:sift.tags.v1)
        pub mod v1 {
            include!("sift.tags.v1.rs");
            // @@protoc_insertion_point(sift.tags.v1)
        }
        // @@protoc_insertion_point(attribute:sift.tags.v2)
        pub mod v2 {
            include!("sift.tags.v2.rs");
            // @@protoc_insertion_point(sift.tags.v2)
        }
    }
    pub mod test_reports {
        // @@protoc_insertion_point(attribute:sift.test_reports.v1)
        pub mod v1 {
            include!("sift.test_reports.v1.rs");
            // @@protoc_insertion_point(sift.test_reports.v1)
        }
    }
    pub mod unit {
        // @@protoc_insertion_point(attribute:sift.unit.v2)
        pub mod v2 {
            include!("sift.unit.v2.rs");
            // @@protoc_insertion_point(sift.unit.v2)
        }
    }
    pub mod user_attributes {
        // @@protoc_insertion_point(attribute:sift.user_attributes.v1)
        pub mod v1 {
            include!("sift.user_attributes.v1.rs");
            // @@protoc_insertion_point(sift.user_attributes.v1)
        }
    }
    pub mod user_defined_functions {
        // @@protoc_insertion_point(attribute:sift.user_defined_functions.v1)
        pub mod v1 {
            include!("sift.user_defined_functions.v1.rs");
            // @@protoc_insertion_point(sift.user_defined_functions.v1)
        }
    }
    pub mod user_groups {
        // @@protoc_insertion_point(attribute:sift.user_groups.v2)
        pub mod v2 {
            include!("sift.user_groups.v2.rs");
            // @@protoc_insertion_point(sift.user_groups.v2)
        }
    }
    pub mod users {
        // @@protoc_insertion_point(attribute:sift.users.v2)
        pub mod v2 {
            include!("sift.users.v2.rs");
            // @@protoc_insertion_point(sift.users.v2)
        }
    }
    pub mod views {
        // @@protoc_insertion_point(attribute:sift.views.v1)
        pub mod v1 {
            include!("sift.views.v1.rs");
            // @@protoc_insertion_point(sift.views.v1)
        }
        // @@protoc_insertion_point(attribute:sift.views.v2)
        pub mod v2 {
            include!("sift.views.v2.rs");
            // @@protoc_insertion_point(sift.views.v2)
        }
    }
    pub mod webhooks {
        // @@protoc_insertion_point(attribute:sift.webhooks.v1)
        pub mod v1 {
            include!("sift.webhooks.v1.rs");
            // @@protoc_insertion_point(sift.webhooks.v1)
        }
    }
}
